@@ -1,4 +1,4 @@
-# LaTeX2HTML 2002-2-1 (1.71)
+# LaTeX2HTML 2002-2-1 (1.70)
 # Associate internals original text with physical files.
 
 
@@ -38,10 +38,6 @@ $key = q/load/;
 $ref_files{$key} = "$dir".q|node4.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/analysis/;
-$ref_files{$key} = "$dir".q|node6.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/Actions_for_controlling_scheduling_of_URLs/;
 $ref_files{$key} = "$dir".q|node16.html|; 
 $noresave{$key} = "$nosave";
@@ -242,10 +238,6 @@ $key = q/httpProxy/;
 $ref_files{$key} = "$dir".q|node13.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/relTextPlugin/;
-$ref_files{$key} = "$dir".q|node13.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/doCheckRecord/;
 $ref_files{$key} = "$dir".q|node13.html|; 
 $noresave{$key} = "$nosave";
@@ -394,10 +386,6 @@ $key = q/gory/;
 $ref_files{$key} = "$dir".q|node11.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/SVMmodel/;
-$ref_files{$key} = "$dir".q|node13.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/cite_Yang_99/;
 $ref_files{$key} = "$dir".q|node10.html|; 
 $noresave{$key} = "$nosave";
@@ -410,10 +398,6 @@ $key = q/_get/;
 $ref_files{$key} = "$dir".q|node16.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/analysePlugin/;
-$ref_files{$key} = "$dir".q|node13.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/new_/;
 $ref_files{$key} = "$dir".q|node16.html|; 
 $noresave{$key} = "$nosave";
@@ -422,14 +406,14 @@ $key = q/gettingstarted/;
 $ref_files{$key} = "$dir".q|node4.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/LICENSE/;
-$ref_files{$key} = "$dir".q|node16.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/exclude/;
 $ref_files{$key} = "$dir".q|node13.html|; 
 $noresave{$key} = "$nosave";
 
+$key = q/LICENSE/;
+$ref_files{$key} = "$dir".q|node16.html|; 
+$noresave{$key} = "$nosave";
+
 $key = q/cite_GolubChall/;
 $ref_files{$key} = "$dir".q|node10.html|; 
 $noresave{$key} = "$nosave";
@@ -482,10 +466,6 @@ $key = q/UAtimeout/;
 $ref_files{$key} = "$dir".q|node13.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/MySQLfulltext/;
-$ref_files{$key} = "$dir".q|node13.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/baseConfigDir/;
 $ref_files{$key} = "$dir".q|node13.html|; 
 $noresave{$key} = "$nosave";
@@ -506,14 +486,14 @@ $key = q/sessionids/;
 $ref_files{$key} = "$dir".q|node13.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/_reset_/;
-$ref_files{$key} = "$dir".q|node16.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/cite_ardo99:_online99/;
 $ref_files{$key} = "$dir".q|node10.html|; 
 $noresave{$key} = "$nosave";
 
+$key = q/_reset_/;
+$ref_files{$key} = "$dir".q|node16.html|; 
+$noresave{$key} = "$nosave";
+
 $key = q/termlist/;
 $ref_files{$key} = "$dir".q|node6.html|; 
 $noresave{$key} = "$nosave";
@@ -526,11 +506,11 @@ $key = q/InstTest/;
 $ref_files{$key} = "$dir".q|node16.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/Actions_loading_or_recycling_URLs_for_crawling/;
+$key = q/topic_reset_topic_rewind_topic_add_topic_get_/;
 $ref_files{$key} = "$dir".q|node16.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/topic_reset_topic_rewind_topic_add_topic_get_/;
+$key = q/Actions_loading_or_recycling_URLs_for_crawling/;
 $ref_files{$key} = "$dir".q|node16.html|; 
 $noresave{$key} = "$nosave";
 
@@ -550,14 +530,14 @@ $key = q/debian/;
 $ref_files{$key} = "$dir".q|node4.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/WaitIntervalHarvesterLockSuccess/;
-$ref_files{$key} = "$dir".q|node13.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/_rewind_/;
 $ref_files{$key} = "$dir".q|node16.html|; 
 $noresave{$key} = "$nosave";
 
+$key = q/WaitIntervalHarvesterLockSuccess/;
+$ref_files{$key} = "$dir".q|node13.html|; 
+$noresave{$key} = "$nosave";
+
 $key = q/cite_Svenonius_2000/;
 $ref_files{$key} = "$dir".q|node10.html|; 
 $noresave{$key} = "$nosave";
